@@ -1,4 +1,4 @@
-#   Copyright 2020-2021 Exactpro (Exactpro Systems Limited)
+#   Copyright 2020-2022 Exactpro (Exactpro Systems Limited)
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -12,9 +12,10 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-from importlib.metadata import version, PackageNotFoundError
+from pkg_resources import DistributionNotFound, get_distribution
+from th2_common_utils.message_fields_access import *
 
 try:
-    print(f"Use th2-common=={version('th2_common')}")
-except PackageNotFoundError:
-    print(f"th2-common lib not found")
+    print(f"Using th2-common=={get_distribution('th2_common').version}")
+except DistributionNotFound:
+    print('th2-common package is not installed')
