@@ -1,4 +1,4 @@
-#   Copyright 2021-2021 Exactpro (Exactpro Systems Limited)
+#   Copyright 2021-2022 Exactpro (Exactpro Systems Limited)
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -12,10 +12,27 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-from th2_grpc_common.common_pb2 import MessageID, MessageGroupBatch, AnyMessage, EventBatch, Direction
-from typing import List, Tuple
+from typing import List, Optional, Tuple
 
-from th2_common.schema.metrics.common_metrics import CommonMetrics
+from th2_grpc_common.common_pb2 import AnyMessage, Direction, EventBatch, MessageGroup, MessageGroupBatch, MessageID
+
+from th2_common.schema.message.configuration.message_configuration import MessageRouterConfiguration, \
+    MqRouterFilterConfiguration
+import th2_common.schema.metrics.common_metrics as common_metrics
+
+
+def get_filters(configuration: MessageRouterConfiguration,
+                aliases: List[str]) -> List[List[MqRouterFilterConfiguration]]:
+    return [configuration.queues[alias].filters for alias in aliases]
+
+
+def get_sequence(group: MessageGroup) -> Optional[int]:
+    if group.messages[0].HasField('raw_message'):
+        return group.messages[0].raw_message.metadata.id.sequence
+    elif group.messages[0].HasField('message'):
+        return group.messages[0].message.metadata.id.sequence
+
+    return None
 
 
 def get_session_alias_and_direction(message_id: MessageID) -> Tuple[str, str]:
@@ -28,12 +45,12 @@ def get_session_alias_and_direction_group(any_message: AnyMessage) -> Tuple[str,
     elif any_message.HasField('raw_message'):
         return get_session_alias_and_direction(any_message.raw_message.metadata.id)
     else:
-        return CommonMetrics.UNKNOWN_LABELS
+        return common_metrics.UNKNOWN_LABELS
 
 
 def get_debug_string(class_name: str, ids: List[MessageID]) -> str:
     session_alias, direction = get_session_alias_and_direction(ids[0])
-    sequences = ''.join([str(i.sequence) for i in ids])
+    sequences = ', '.join([str(i.sequence) for i in ids])
     return f'{class_name}: session_alias = {session_alias}, direction = {direction}, sequences = {sequences}'.strip()
 
 
@@ -45,14 +62,15 @@ def get_debug_string_group(group_batch: MessageGroupBatch) -> str:
     messages = [message for group in group_batch.groups for message in group.messages]
     session_alias, direction = get_session_alias_and_direction_group(messages[0])
     sequences = []
+
     for message in messages:
         if message.HasField('message'):
             sequences.append(str(message.message.metadata.id.sequence))
         elif message.HasField('raw_message'):
             sequences.append(str(message.raw_message.metadata.id.sequence))
-    sequences = ''.join(sequences)
+    sequences_string = ''.join(sequences)
 
     return f'MessageGroupBatch: ' \
            f'session_alias = {session_alias}, ' \
            f'direction = {direction}, ' \
-           f'sequences = {sequences}'.strip()
+           f'sequences_string = {sequences_string}'.strip()
